@@ -242,7 +242,7 @@ class _calendar():
                 return sorted([t, dt(t0)])
         elif is_bump(t1):
             if t0 is None:
-                return [t, self.dt_bump(t, t1)]
+                return [TMIN, self.dt_bump(t, t1)]
             elif is_bump(t0):
                 return [self.dt_bump(t, t0), dt_bump(t, t1)]
             else:
@@ -251,7 +251,7 @@ class _calendar():
         else:
             t1 = dt(t1)
             if t0 is None:
-                return [t, t1]
+                return [TMIN, t1]
             elif is_bump(t0):
                 return [self.dt_bump(t1, t0), t1]
             else:
@@ -535,6 +535,10 @@ class Calendar(Dict, _calendar):
             nearby business day
 
         """
+        if isinstance(date, (list, tuple)):
+            return type(date)([self.adjust(d, adj) for d in date])
+        if isinstance(date, dict):
+            return type(date)({k : self.adjust(d, adj) for k,d in date.items()})
         adj = (adj or self.adj or 'm').lower()
         t = ymd(date)
         t = datetime.datetime(t.year, t.month, t.day)
