@@ -5,6 +5,7 @@ import datetime
 from functools import partial
 import re
 from enum import Enum
+import json
 
 from pyg_base._logger import logger
 
@@ -26,6 +27,14 @@ def is_primitive(value):
     value is None or isinstance(value, _primitives)
 
 
+def is_jsonable(value):
+    try:
+        json.dumps(value)
+        return True
+    except (TypeError, OverflowError):
+        return False
+
+
 def is_series(value):
     """ is value a pd.Series"""
     return isinstance(value, pd.Series)
